@@ -20,4 +20,5 @@ DEFAULT_POPUP_WIDTH = 400
 
 # Standard menus and buttons sizes
 BUTTON_SIZE = (200, 60)
-DEFAULT_CLOSE_BUTTON_SIZE = (150, 50)
+IMAGE_BUTTON_SIZE = (250, 60)
+CLOSE_BUTTON_SIZE = (150, 50)
